Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(387)

Unified Diff: third_party/WebKit/public/platform/WebURLRequest.h

Issue 2642793005: Create a Lite Page bit for previews and fallback to Lo-Fi (Closed)
Patch Set: remove unused frame_messages.h code Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/renderer/render_frame_impl.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/public/platform/WebURLRequest.h
diff --git a/third_party/WebKit/public/platform/WebURLRequest.h b/third_party/WebKit/public/platform/WebURLRequest.h
index 37aedaee7b4ad260354a5d03b7b31d7abaf541d9..591d09f1fe17fb93415c11f3e2243e4f4772cbc5 100644
--- a/third_party/WebKit/public/platform/WebURLRequest.h
+++ b/third_party/WebKit/public/platform/WebURLRequest.h
@@ -136,18 +136,22 @@ class WebURLRequest {
ReportIntent, // Report metrics with UI action displayed intent.
};
- // The Previews state which determines whether to request a Preview version of
+ typedef int PreviewsState;
+
+ // The Previews types which determines whether to request a Preview version of
// the resource.
- enum PreviewsState {
+ enum PreviewsTypes {
PreviewsUnspecified = 0, // Let the browser process decide whether or
// not to request Preview types.
ServerLoFiOn = 1 << 0, // Request a Lo-Fi version of the resource
// from the server.
ClientLoFiOn = 1 << 1, // Request a Lo-Fi version of the resource
// from the client.
- PreviewsNoTransform = 1 << 2, // Explicitly forbid Previews
+ ServerLitePageOn = 1 << 2, // Request a Lite Page version of the
+ // resource from the server.
+ PreviewsNoTransform = 1 << 3, // Explicitly forbid Previews
// transformations.
- PreviewsOff = 1 << 3, // Request a normal (non-Preview) version of
+ PreviewsOff = 1 << 4, // Request a normal (non-Preview) version of
// the resource. Server transformations may
// still happen if the page is heavy.
PreviewsStateLast = PreviewsOff
« no previous file with comments | « content/renderer/render_frame_impl.cc ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698